<?php

namespace Drupal\sl_match\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\views\Views;

/**
 * Provides a 'SL Match tabs' block.
 *
 * @Block(
 *  id = "sl_match_tabs",
 *  admin_label = @Translation("SL Match tabs"),
 *  context_definitions = {
 *    "node" = @ContextDefinition("entity:node", label = @Translation("Node"), required = FALSE),
 *  }
 * )
 */
class SLMatchTabs extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function getContextMapping() {
    $mapping = parent::getContextMapping();
    // By default, get the node from the URL.
    return $mapping ?: ['node' => '@node.node_route_context:node'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $build = [];
    $prematch_info = '';
    $build['sl_match_tabs']['#rosters_set'] = FALSE;
    // To be used in sl_match node page.
    if ($node = $this->getContextValue('node')) {
      if ($node->bundle() == 'sl_match') {
        if (!$node->field_sl_match_prematch_info->isEmpty()) {
          $prematch_info = $node->field_sl_match_prematch_info->view('teaser');
        }
        $match_status = $node->field_sl_match_status->value;

        if ($match_status == 'played') {

          $rosters = [
            'home_ini' => [
              'field' => 'field_sl_match_home_inirosters',
              'block' => 'block_2',
            ],
            'away_ini' => [
              'field' => 'field_sl_match_away_inirosters',
              'block' => 'block_1',
            ],
            'home_subs' => [
              'field' => 'field_sl_match_home_inisubs',
              'block' => 'block_4',
            ],
            'away_subs' => [
              'field' => 'field_sl_match_away_inisubs',
              'block' => 'block_3',
            ],
            'home_coach' => [
              'field' => 'field_sl_match_home_coach',
              'block' => 'block_5',
            ],
            'away_coach' => [
              'field' => 'field_sl_match_away_coach',
              'block' => 'block_6',
            ],
          ];

          // Rosters.
          foreach ($rosters as $key => $info) {
            if ($node->get($info['field'])->isEmpty()) {
              continue;
            }

            $view = Views::getView('sl_match_rosters');
            $view->setArguments([$node->id()]);
            $view->setDisplay($info['block']);
            $view->preExecute();
            $view->execute();
            $view->buildRenderable($info['block'], [$node->id()]);
            $build['sl_match_tabs']['#' . $key] = $view->render();
            $build['sl_match_tabs']['#rosters_set'] = TRUE;
          }

          $moments = [
            'home_moments' => [
              'field' => 'field_sl_match_home_moments',
              'block' => 'block_1',
            ],
            'away_moments' => [
              'field' => 'field_sl_match_away_moments',
              'block' => 'block_2',
            ],
          ];

          // Rosters.
          foreach ($moments as $key => $info) {
            if ($node->get($info['field'])->isEmpty()) {
              continue;
            }

            $view = Views::getView('sl_match_moments');
            $view->setArguments([$node->id()]);
            $view->setDisplay($info['block']);
            $view->preExecute();
            $view->execute();
            $view->buildRenderable($info['block'], [$node->id()]);
            $build['sl_match_tabs']['#' . $key] = $view->render();
            $build['sl_match_tabs']['#rosters_set'] = TRUE;
          }

          $extra_classes_rosters[] = [];
          $build['sl_match_tabs']['#extra_classes_rosters'] = implode(" ", [
            'home-' . $node->field_sl_match_team_home->entity->field_sl_club->target_id,
            'away-' . $node->field_sl_match_team_away->entity->field_sl_club->target_id,
          ]);

        }
      }
    }

    $build['sl_match_tabs']['#theme'] = 'sl_match_tabs';
    if (!empty($prematch_info)) {
      $build['sl_match_tabs']['#prematch_info'] = $prematch_info;
    }
    $build['sl_match_tabs']['#match_status'] = $match_status;

    return $build;
  }

}
